@@ -4,6 +4,8 @@ from qwak.clients.alerts_registry import AlertingRegistryClient
 from qwak.clients.alerts_registry.channel import Channel
 from tabulate import tabulate
 
+from qwak_sdk.commands._logic.tools import list_of_messages_to_json_str
+
 
 def execute_list_channels():
     alerts_client = AlertingRegistryClient()
@@ -12,4 +14,10 @@ def execute_list_channels():
     data = []
     for c_id, c in channels:
         data.append([c_id, c.name, type(c.channel_conf).__name__, c.__dict__])
-    print(tabulate(data, headers=columns))
+    return tabulate(data, headers=columns)
+
+
+def execute_json_format_list_channels():
+    alerts_client = AlertingRegistryClient()
+    channels = alerts_client.list_alerting_channel_from_client().description
+    return list_of_messages_to_json_str(channels)
