@@ -15,7 +15,7 @@ AUTOMATION = "automation"
 
 
 @click.group(
-    name="audience",
+    name="audiences",
     help="Manage audiences",
 )
 def audience_commands_group():
