@@ -1,6 +1,8 @@
 import click
 
+from qwak_sdk.commands.feature_store.backfill.ui import backfill
 from qwak_sdk.commands.feature_store.delete.ui import delete_fs_object
+from qwak_sdk.commands.feature_store.execution.ui import execution_status
 from qwak_sdk.commands.feature_store.list.ui import list_feature_sets
 from qwak_sdk.commands.feature_store.pause.ui import pause_feature_set
 from qwak_sdk.commands.feature_store.register.ui import register_fs_objects
@@ -23,3 +25,5 @@ feature_store_commands_group.add_command(pause_feature_set)
 feature_store_commands_group.add_command(resume_feature_set)
 feature_store_commands_group.add_command(trigger_feature_set)
 feature_store_commands_group.add_command(register_fs_objects)
+feature_store_commands_group.add_command(backfill)
+feature_store_commands_group.add_command(execution_status)
