@@ -16,10 +16,19 @@ from qwak_sdk.tools.colors import Color
     required=False,
     help="Model description",
 )
-def model_create(name, description, project, project_id, **kwargs):
+@click.option(
+    "--format",
+    default="text",
+    show_default=True,
+    type=click.Choice(["text", "json"], case_sensitive=True),
+    metavar="FORMAT",
+    required=False,
+    help="The formatting style for commands output (choose from text, json)",
+)
+def model_create(name, description, project, project_id, format, **kwargs):
     try:
         response = execute_model_create(name, description, project, project_id)
-        if kwargs["format"] == "json":
+        if format == "json":
             output_as_json(response)
         else:
             print(f"Model created\nmodel id : {response.model_id}")
