@@ -8,9 +8,18 @@ from qwak_sdk.inner.tools.cli_tools import QwakCommand
 @click.command("delete", cls=QwakCommand)
 @click.option("--project-id", metavar="NAME", required=True, help="Project id")
 @click.option("--model-id", metavar="NAME", required=True, help="Model name")
-def model_delete(project_id, model_id, **kwargs):
+@click.option(
+    "--format",
+    default="text",
+    show_default=True,
+    type=click.Choice(["text", "json"], case_sensitive=True),
+    metavar="FORMAT",
+    required=False,
+    help="The formatting style for commands output (choose from text, json)",
+)
+def model_delete(project_id, model_id, format, **kwargs):
     response = execute_model_delete(project_id, model_id)
-    if kwargs["format"] == "json":
+    if format == "json":
         output_as_json(response)
     else:
         print(f"Model deleted\nmodel id : {model_id}")
