@@ -2,22 +2,24 @@ from dataclasses import dataclass, field
 from enum import Enum
 from typing import Dict, List, Optional, Tuple, Union
 
+from qwak.inner.tool.run_config import (
+    ConfigCliMap,
+    QwakConfigBase,
+    YamlConfigMixin,
+    validate_bool,
+    validate_enum,
+    validate_float,
+    validate_int,
+    validate_list_of_strings,
+    validate_string,
+)
+from qwak.inner.tool.run_config.utils import validate_variations
+
 from qwak_sdk.commands.audience._logic.config.v1.audience_config import AudienceConfig
 from qwak_sdk.commands.auto_scalling._logic.config.config import AutoScaling
 from qwak_sdk.commands.models.deployments.deploy._logic.get_latest_successful_build import (
     get_latest_successful_build_from_model,
 )
-from qwak_sdk.common.run_config import (
-    ConfigCliMap,
-    QwakConfigBase,
-    YamlConfigMixin,
-    validate_bool,
-    validate_enum,
-    validate_int,
-    validate_list_of_strings,
-    validate_string,
-)
-from qwak_sdk.common.run_config.utils import validate_float, validate_variations
 
 
 class CompressionTypes(Enum):
@@ -39,7 +41,7 @@ class PurchaseOption(Enum):
     ONDEMAND = "ondemand"
 
 
-CONFIG_MAPPING: List[ConfigCliMap] = [
+DEPLOYMENT_CLI_CONFIG_MAPPING: List[ConfigCliMap] = [
     # Stream
     # General
     ConfigCliMap("model_id", "model_id", validate_string, True),
@@ -138,6 +140,12 @@ CONFIG_MAPPING: List[ConfigCliMap] = [
     ConfigCliMap(
         "iam_role_arn", "advanced_options.iam_role_arn", validate_string, False
     ),
+    ConfigCliMap(
+        "service_account_key_secret_name",
+        "advanced_options.service_account_key_secret_name",
+        validate_string,
+        False,
+    ),
     ConfigCliMap(
         "purchase_option",
         "advanced_options.purchase_option",
@@ -164,7 +172,7 @@ class DeployConfig(YamlConfigMixin, QwakConfigBase):
 
     @property
     def _config_mapping(self) -> List[ConfigCliMap]:
-        return CONFIG_MAPPING
+        return DEPLOYMENT_CLI_CONFIG_MAPPING
 
     @dataclass
     class Stream:
@@ -238,7 +246,8 @@ class DeployConfig(YamlConfigMixin, QwakConfigBase):
     @dataclass
     class AdvancedOptions:
         iam_role_arn: str = field(default=None)
-        purchase_option: str = field(default=PurchaseOption.SPOT.value)
+        purchase_option: str = field(default="")
+        service_account_key_secret_name: str = field(default=None)
 
     model_id: str = field(default="")
     build_id: str = field(default="")
