@@ -1,7 +1,5 @@
-from copy import deepcopy
-
 from _qwak_proto.qwak.builds.builds_pb2 import SUCCESSFUL
-from qwak.clients.build_management.client import BuildsManagementClient
+from qwak.clients.build_orchestrator import BuildOrchestratorClient
 from qwak.clients.model_management.client import ModelsManagementClient
 from qwak.exceptions import QwakException
 
@@ -20,12 +18,11 @@ def get_latest_successful_build_from_model(model_id: str) -> str:
     """
     model = ModelsManagementClient().get_model(model_id)
     model_uuid = model.uuid
-    last_successful_build = BuildsManagementClient().list_builds(model_uuid)
-    builds = deepcopy(last_successful_build.builds)
-    builds = [build for build in builds if build.build_status == SUCCESSFUL]
-    builds.sort(key=lambda r: r.created_at.seconds)
+    all_builds = BuildOrchestratorClient().list_builds(model_uuid).build
+    builds = [build for build in all_builds if build.build_status == SUCCESSFUL]
+    builds.sort(key=lambda r: r.audit.created_at.seconds)
 
     if not builds:
         raise QwakException(f"Unable to find successful build for model {model_id}")
 
-    return builds[-1].build_spec.build_id
+    return builds[-1].buildId
