@@ -7,24 +7,14 @@ from _qwak_proto.qwak.deployment.deployment_pb2 import (
     RealTimeConfig,
     ServingStrategy,
     TrafficConfig,
-    Variation,
-)
-from _qwak_proto.qwak.deployment.deployment_service_pb2 import (
-    GetDeploymentStatusResponse,
 )
 from _qwak_proto.qwak.ecosystem.v0.ecosystem_pb2 import UserContextEnvironmentDetails
 from qwak.exceptions import QwakException
 
 from qwak_sdk.commands.audience._logic.config.v1.audience_config import AudienceConfig
-from qwak_sdk.commands.models._logic.variations import (
-    create_variation_from_variation_config,
-)
 from qwak_sdk.commands.models.deployments.deploy._logic.deploy_config import (
     DeployConfig,
 )
-from qwak_sdk.commands.models.deployments.deploy._logic.variations import (
-    get_variations_for_deploy,
-)
 
 
 def create_realtime_serving_strategy(
@@ -32,7 +22,6 @@ def create_realtime_serving_strategy(
     audiences: List[AudienceConfig],
     fallback_variation: str,
     variation_name: str,
-    variations: List[Variation],
     variation_protected_state: bool = False,
 ) -> ServingStrategy:
     return ServingStrategy(
@@ -41,7 +30,6 @@ def create_realtime_serving_strategy(
                 auto_scaling_config=auto_scaling,
                 traffic_config=TrafficConfig(
                     selected_variation_name=variation_name,
-                    variations=variations,
                     audience_routes_entries=[
                         audience.to_audience_route_entry(index)
                         for index, audience in enumerate(audiences)
@@ -56,7 +44,6 @@ def create_realtime_serving_strategy(
 
 def create_realtime_serving_strategy_from_deploy_config(
     deploy_config: DeployConfig,
-    model_traffic: GetDeploymentStatusResponse,
     environment_name_to_config: Dict[str, UserContextEnvironmentDetails],
 ) -> Dict[str, ServingStrategy]:
     serving_strategies = {}
@@ -70,34 +57,12 @@ def create_realtime_serving_strategy_from_deploy_config(
         else None
     )
     for env_name, env_config in environment_name_to_config.items():
-        env_variations_response = model_traffic.environment_to_model_traffic.get(
-            env_config.id
-        )
-        existing_variation = (
-            env_variations_response.variations if env_variations_response else []
-        )
         try:
-            variations = []
-            if not deploy_config.realtime.audiences:
-                variations = get_variations_for_deploy(
-                    variation_name=variation_name,
-                    existing_variations=existing_variation,
-                    requested_variations=list(
-                        map(
-                            create_variation_from_variation_config,
-                            deploy_config.realtime.variations,
-                        )
-                    ),
-                    environment_name=env_name,
-                    variation_protected_state=variation_protected_state,
-                )
-
             serving_strategies[env_config.id] = create_realtime_serving_strategy(
                 auto_scaling,
                 deploy_config.realtime.audiences,
                 fallback_variation,
                 variation_name,
-                variations,
                 variation_protected_state,
             )
 
