@@ -14,6 +14,9 @@ from qwak_sdk.commands.models.deployments.deploy._logic.deploy_config import (
 from qwak_sdk.commands.models.deployments.deploy._logic.deployment_response_handler import (
     client_deployment,
 )
+from qwak_sdk.commands.models.deployments.deploy._logic.local_deployment import (
+    local_deploy,
+)
 from qwak_sdk.commands.models.deployments.deploy.realtime._logic.deploy_executor import (
     RealtimeDeployExecutor,
 )
@@ -84,6 +87,11 @@ logger = get_qwak_logger()
     type=str,
     help="Custom IAM Role ARN.",
 )
+@click.option(
+    "--service-account-key-secret-name",
+    type=str,
+    help="Custom service account for Gcp.",
+)
 @click.option(
     "--max-batch-size",
     type=int,
@@ -108,6 +116,12 @@ logger = get_qwak_logger()
     default=False,
     help="Waiting for deployments to be ready",
 )
+@click.option(
+    "--local",
+    is_flag=True,
+    default=False,
+    help="Deploy the model container locally, for development purposes only",
+)
 @click.option(
     "-v",
     "--verbose",
@@ -160,18 +174,25 @@ logger = get_qwak_logger()
     "--protected",
     "variation_protected_state",
     required=False,
-    type=bool,
+    is_flag=True,
     default=False,
-    help="Whether the deployment variation is protected . Default is False",
+    help="Whether the deployment variation is protected. Default is false",
 )
 def realtime(
-    verbose: bool, from_file: Optional[str], out_conf: bool, sync: bool, **kwargs
+    verbose: bool,
+    from_file: Optional[str],
+    out_conf: bool,
+    sync: bool,
+    local: bool,
+    **kwargs,
 ):
     set_qwak_logger_stdout_verbosity_level(verbose + 1)
-    deploy_realtime(from_file, out_conf, sync, **kwargs)
+    deploy_realtime(from_file, out_conf, sync, local, **kwargs)
 
 
-def deploy_realtime(from_file: Optional[str], out_conf: bool, sync: bool, **kwargs):
+def deploy_realtime(
+    from_file: Optional[str], out_conf: bool, sync: bool, local: bool, **kwargs
+):
     config: DeployConfig = config_handler(
         config=DeployConfig,
         from_file=from_file,
@@ -179,6 +200,10 @@ def deploy_realtime(from_file: Optional[str], out_conf: bool, sync: bool, **kwar
         sections=("realtime", "autoscaling"),
         **kwargs,
     )
-    if not out_conf:
+
+    if local:
+        local_deploy(config)
+
+    elif not out_conf:
         deploy_executor = RealtimeDeployExecutor(config)
         client_deployment(deploy=deploy_executor, sync=sync)
