@@ -156,6 +156,13 @@ logger = get_qwak_logger()
     help="The instance size to run batch on - 'small', 'medium', 'large', etc...",
     default=None,
 )
+@click.option(
+    "--purchase-option",
+    required=False,
+    type=str,
+    help="The instance purchase option 'on-demand' or 'spot'",
+    default=None,
+)
 def execution_start(from_file: str, out_conf: bool, **kwargs):
     if kwargs["source_folder"].startswith("file:") and kwargs[
         "destination_folder"
