@@ -13,7 +13,16 @@ from qwak_sdk.inner.tools.cli_tools import QwakCommand
     required=False,
     help="Project description",
 )
-def create_project(name, description, format: str = "text", *args, **kwargs):
+@click.option(
+    "--format",
+    default="text",
+    show_default=True,
+    type=click.Choice(["text", "json"], case_sensitive=True),
+    metavar="FORMAT",
+    required=False,
+    help="The formatting style for commands output (choose from text, json)",
+)
+def create_project(name, description, format, *args, **kwargs):
     response = execute_create(name, description)
     if format == "json":
         output_as_json(response)
