@@ -21,7 +21,16 @@ def parse_project(project):
 
 
 @click.command("list", cls=QwakCommand)
-def projects_list(format: str = "text", **kwargs):
+@click.option(
+    "--format",
+    default="text",
+    show_default=True,
+    type=click.Choice(["text", "json"], case_sensitive=True),
+    metavar="FORMAT",
+    required=False,
+    help="The formatting style for commands output (choose from text, json)",
+)
+def projects_list(format, **kwargs):
     projects_data = execute_list()
     if format == "json":
         output_as_json(projects_data)
