@@ -1,14 +1,14 @@
 from dataclasses import dataclass, field
 from typing import List
 
-from qwak_sdk.common.run_config import (
+from qwak.inner.tool.run_config import (
     ConfigCliMap,
     QwakConfigBase,
     YamlConfigMixin,
     validate_string,
 )
 
-CONFIG_MAPPING: List[ConfigCliMap] = [
+WORKSPACE_CLI_CONFIG_MAPPING: List[ConfigCliMap] = [
     ConfigCliMap("workspace_id", "workspace.workspace_id", validate_string, False),
     ConfigCliMap("name", "workspace.name", validate_string, False),
     ConfigCliMap("instance", "workspace.instance", validate_string, False),
@@ -23,7 +23,7 @@ class WorkspaceConfig(YamlConfigMixin, QwakConfigBase):
 
     @property
     def _config_mapping(self) -> List[ConfigCliMap]:
-        return CONFIG_MAPPING
+        return WORKSPACE_CLI_CONFIG_MAPPING
 
     @dataclass
     class Workspace:
