@@ -1,7 +1,7 @@
+from qwak.exceptions import QwakGeneralBuildException, QwakSuggestionException
+
 from .qwak_command_exception import QwakCommandException
-from .qwak_general_build_exception import QwakGeneralBuildException
 from .qwak_resource_not_found import QwakResourceNotFound
-from .qwak_suggestion_exception import QwakSuggestionException
 
 __all__ = [
     "QwakGeneralBuildException",
