@@ -1,4 +1,4 @@
-from qwak_sdk.exceptions import QwakSuggestionException
+from qwak.exceptions import QwakSuggestionException
 
 
 class QwakDeployNewBuildFailedException(QwakSuggestionException):
